==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>支持者</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>創作者</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>全体像</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>プレゼンテーション</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>発行者</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>ライブラリブラウザ</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>リスト</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>ソースフォルダを選択</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation></translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>アイコンをアップデート...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translation>ファイル:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>フォルダ:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>ライセンス:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>属性:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>創作者:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>ライブラリインデックスを更新中:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translation>DBエラー</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin ライブラリブラウザ: DBに接続できません。
Driver error: %1
Database error: %2
Database file: %3
ライブラリブラウザは利用できません。</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;I 挿入</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;E スクリプトファイルを編集...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>&amp;SVGファイルを開く...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;O 開く...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;E 編集...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>ファイルブラウザ</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;S %1を表示...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;R お気に入りから削除</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;A お気に入りに追加</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;R アイコンを再生成</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;R アイコンを再生成</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>&amp;L ライブラリブラウザ</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>同期</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>開始時のインデックス検索を更新</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>ディスプレイオプション</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>アイコンサイズ:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>ビューモード:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>検索結果の
アイテム数:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>ライブラリソース</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>追加...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>アップ</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>ダウン</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>ファイルシステム</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Tags</source>
        <translation>タグ</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>探す:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>タグ選択をリセット</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation></translation>
    </message>
    <message>
        <location line="+106"/>
        <source>Favorites</source>
        <translation>お気に入り</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Update DB from file system</source>
        <translation>ファイルシステムからDBをアップデート</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>支持者</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>創作者</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>全体像</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>プレゼンテーション</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>発行者</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>ライブラリブラウザ</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>リスト</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>ソースフォルダを選択</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>ページ %1 / %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>アイコンをアップデート...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translation>ファイル:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>フォルダ:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>ライセンス:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>属性:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>創作者:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>ライブラリインデックスを更新中:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translation>DBエラー</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin ライブラリブラウザ: DBに接続できません。
Driver error: %1
Database error: %2
Database file: %3
ライブラリブラウザは利用できません。</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;I 挿入</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;E スクリプトファイルを編集...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>&amp;SVGファイルを開く...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;O 開く...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;E 編集...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>ファイルブラウザ</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;S %1を表示...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;R お気に入りから削除</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;A お気に入りに追加</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;R アイコンを再生成</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;R アイコンを再生成</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>&amp;L ライブラリブラウザ</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>同期</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>開始時のインデックス検索を更新</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>ディスプレイオプション</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>アイコンサイズ:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>ビューモード:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>検索結果の
アイテム数:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>ライブラリソース</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>追加...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>アップ</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>ダウン</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>ファイルシステム</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">タグ</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Look for:</source>
        <translation>探す:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>タグ選択をリセット</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Favorites</source>
        <translation>お気に入り</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Insert selected item into drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>ファイルシステムからDBをアップデート</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
